==> jc-1.4.0.tar.gz: gnu/xml/pipeline/XsltFilter.h <==
// public final class gnu.xml.pipeline.XsltFilter

// class file dependencies
// @dep_class c2c3ed4310a669e3 gnu_xml_pipeline_EventFilter
// @dep_class cdee9bf5c2b6985e gnu_xml_pipeline_XsltFilter
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header gnu_xml_pipeline_EventFilter

#include "gnu/xml/pipeline/EventFilter.h"

#ifndef _JC_gnu_xml_pipeline_XsltFilter_H_
#define _JC_gnu_xml_pipeline_XsltFilter_H_

// Forward structure declarations
struct _jc_gnu_xml_pipeline_EventConsumer$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_xml_pipeline_XsltFilter$sub_refs	_jc_gnu_xml_pipeline_XsltFilter$sub_refs;
typedef struct _jc_gnu_xml_pipeline_XsltFilter$sub_nonrefs	_jc_gnu_xml_pipeline_XsltFilter$sub_nonrefs;
typedef struct _jc_gnu_xml_pipeline_XsltFilter$refs	_jc_gnu_xml_pipeline_XsltFilter$refs;
typedef struct _jc_gnu_xml_pipeline_XsltFilter$nonrefs	_jc_gnu_xml_pipeline_XsltFilter$nonrefs;
typedef struct _jc_gnu_xml_pipeline_XsltFilter$object	_jc_gnu_xml_pipeline_XsltFilter$object;

typedef const struct _jc_gnu_xml_pipeline_XsltFilter$vmethods	_jc_gnu_xml_pipeline_XsltFilter$vmethods;
typedef const struct _jc_gnu_xml_pipeline_XsltFilter$vtable	_jc_gnu_xml_pipeline_XsltFilter$vtable;
typedef const struct _jc_gnu_xml_pipeline_XsltFilter$vtype	_jc_gnu_xml_pipeline_XsltFilter$vtype;

// Constructors
extern void _jc_gnu_xml_pipeline_XsltFilter$method$_init$5ba0db2bca686d90(_jc_env *, struct _jc_gnu_xml_pipeline_XsltFilter$object *, struct _jc_java_lang_String$object *, struct _jc_object *);

// Virtual methods structure
struct _jc_gnu_xml_pipeline_XsltFilter$vmethods {
};

// Vtable
struct _jc_gnu_xml_pipeline_XsltFilter$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_pipeline_EventFilter$vmethods	gnu_xml_pipeline_EventFilter;
	_jc_gnu_xml_pipeline_XsltFilter$vmethods	gnu_xml_pipeline_XsltFilter;
};

// Vtype
struct _jc_gnu_xml_pipeline_XsltFilter$vtype {
	_jc_type			type;
	_jc_gnu_xml_pipeline_XsltFilter$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_pipeline_XsltFilter$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_xml_pipeline_XsltFilter$refs {
    _jc_gnu_xml_pipeline_XsltFilter$sub_refs	gnu_xml_pipeline_XsltFilter;
    _jc_gnu_xml_pipeline_EventFilter$sub_refs	gnu_xml_pipeline_EventFilter;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_pipeline_XsltFilter$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_pipeline_XsltFilter$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_pipeline_EventFilter$sub_nonrefs	gnu_xml_pipeline_EventFilter;
    _jc_gnu_xml_pipeline_XsltFilter$sub_nonrefs	gnu_xml_pipeline_XsltFilter;
};

// Object instance structure
struct _jc_gnu_xml_pipeline_XsltFilter$object {
	_jc_gnu_xml_pipeline_XsltFilter$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_pipeline_XsltFilter$vtype	*vtype;
	_jc_gnu_xml_pipeline_XsltFilter$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_pipeline_XsltFilter$vtype _jc_gnu_xml_pipeline_XsltFilter$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_pipeline_XsltFilter, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_pipeline_XsltFilter$class_object;

#endif	/* _JC_gnu_xml_pipeline_XsltFilter_H_ */

==> jc-1.4.6.tar.gz: gnu/xml/pipeline/XsltFilter.h <==
// public final class gnu.xml.pipeline.XsltFilter

// class file dependencies
// @dep_class c2c3ed4310a669e3 gnu_xml_pipeline_EventFilter
// @dep_class cdee9bf5c2b6985e gnu_xml_pipeline_XsltFilter
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header gnu_xml_pipeline_EventFilter

#include "gnu/xml/pipeline/EventFilter.h"

#ifndef _JC_gnu_xml_pipeline_XsltFilter_H_
#define _JC_gnu_xml_pipeline_XsltFilter_H_

// Forward structure declarations
struct _jc_gnu_xml_pipeline_EventConsumer$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_xml_pipeline_XsltFilter$sub_refs	_jc_gnu_xml_pipeline_XsltFilter$sub_refs;
typedef struct _jc_gnu_xml_pipeline_XsltFilter$sub_nonrefs	_jc_gnu_xml_pipeline_XsltFilter$sub_nonrefs;
typedef struct _jc_gnu_xml_pipeline_XsltFilter$refs	_jc_gnu_xml_pipeline_XsltFilter$refs;
typedef struct _jc_gnu_xml_pipeline_XsltFilter$nonrefs	_jc_gnu_xml_pipeline_XsltFilter$nonrefs;
typedef struct _jc_gnu_xml_pipeline_XsltFilter$object	_jc_gnu_xml_pipeline_XsltFilter$object;

typedef const struct _jc_gnu_xml_pipeline_XsltFilter$vmethods	_jc_gnu_xml_pipeline_XsltFilter$vmethods;
typedef const struct _jc_gnu_xml_pipeline_XsltFilter$vtable	_jc_gnu_xml_pipeline_XsltFilter$vtable;
typedef const struct _jc_gnu_xml_pipeline_XsltFilter$vtype	_jc_gnu_xml_pipeline_XsltFilter$vtype;

// Constructors
extern void _jc_gnu_xml_pipeline_XsltFilter$method$_init$5ba0db2bca686d90(_jc_env *, struct _jc_gnu_xml_pipeline_XsltFilter$object *, struct _jc_java_lang_String$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_gnu_xml_pipeline_XsltFilter$vmethods {
};

// Vtable
struct _jc_gnu_xml_pipeline_XsltFilter$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_pipeline_EventFilter$vmethods	gnu_xml_pipeline_EventFilter;
	_jc_gnu_xml_pipeline_XsltFilter$vmethods	gnu_xml_pipeline_XsltFilter;
};

// Vtype
struct _jc_gnu_xml_pipeline_XsltFilter$vtype {
	_jc_type			type;
	_jc_gnu_xml_pipeline_XsltFilter$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_pipeline_XsltFilter$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_xml_pipeline_XsltFilter$refs {
    _jc_gnu_xml_pipeline_XsltFilter$sub_refs	gnu_xml_pipeline_XsltFilter;
    _jc_gnu_xml_pipeline_EventFilter$sub_refs	gnu_xml_pipeline_EventFilter;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_pipeline_XsltFilter$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_pipeline_XsltFilter$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_pipeline_EventFilter$sub_nonrefs	gnu_xml_pipeline_EventFilter;
    _jc_gnu_xml_pipeline_XsltFilter$sub_nonrefs	gnu_xml_pipeline_XsltFilter;
};

// Object instance structure
struct _jc_gnu_xml_pipeline_XsltFilter$object {
	_jc_gnu_xml_pipeline_XsltFilter$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_pipeline_XsltFilter$vtype	*vtype;
	_jc_gnu_xml_pipeline_XsltFilter$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_pipeline_XsltFilter$vtype _jc_gnu_xml_pipeline_XsltFilter$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_pipeline_XsltFilter, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_pipeline_XsltFilter$class_object;

#endif	/* _JC_gnu_xml_pipeline_XsltFilter_H_ */
